@@ -2,11 +2,17 @@ import pandas as pd
 from filelock import FileLock
 
 
+def rm_none(text:str):
+    if text == 'None':
+        return ''
+    else:
+        return text
+
 def sync_append(*,csv_filepath:str,values:list, delimeter: str =','):
     df = pd.read_csv(csv_filepath)
     assert len(df.columns) == len(values)
     del df
-    values = [f'''"{str(i)}"''' for i in values]
+    values = [f'''"{rm_none(str(i))}"''' for i in values]
     newvalue = str(delimeter.join(values)) + '\n'
 
     lock_path = f"{csv_filepath}.lock"
